E5Gui/E5ComboBox.py

changeset 3670
f0cb7579c0b4
parent 3656
441956d8fce5
child 4021
195a471c327b
diff -r ac84ac3c0f05 -r f0cb7579c0b4 E5Gui/E5ComboBox.py
--- a/E5Gui/E5ComboBox.py	Sat Jul 05 11:41:14 2014 +0200
+++ b/E5Gui/E5ComboBox.py	Sat Jul 05 12:13:23 2014 +0200
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing combobox classes using the eric5 line edits.
+Module implementing combobox classes using the eric6 line edits.
 """
 
 from __future__ import unicode_literals
@@ -14,7 +14,7 @@
 
 class E5ComboBox(QComboBox):
     """
     Class implementing a combobox using the eric5 line edit.
     """
     def __init__(self, parent=None, inactiveText=""):
         """
@@ -52,7 +52,7 @@
 
 class E5ClearableComboBox(E5ComboBox):
     """
     Class implementing a combobox using the eric5 line edit.
     """
     def __init__(self, parent=None, inactiveText=""):
         """
@@ -14,7 +14,7 @@
 class E5ComboBox(QComboBox):
     """
-    Class implementing a combobox using the eric5 line edit.
+    Class implementing a combobox using the eric6 line edit.
     """
     def __init__(self, parent=None, inactiveText=""):
@@ -52,7 +52,7 @@
 class E5ClearableComboBox(E5ComboBox):
     """
-    Class implementing a combobox using the eric5 line edit.
+    Class implementing a combobox using the eric6 line edit.
     """
     def __init__(self, parent=None, inactiveText=""):

eric ide

mercurial